==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/extension/max/action/ext/lang/zh-tw/zentaobiz.php <==
<?php
$lang->action->dynamicAction->bug['fromfeedback']   = '由反饋創建Bug';
$lang->action->dynamicAction->story['fromfeedback'] = '由反饋創建' . $lang->SRCommon;
$lang->action->dynamicAction->task['fromfeedback']  = '由反饋創建任務';
$lang->action->dynamicAction->todo['fromfeedback']  = '由反饋創建待辦';

$lang->action->dynamicAction->deploy['created']       = '創建上線計劃';
$lang->action->dynamicAction->deploy['edited']        = '編輯上線計劃';
$lang->action->dynamicAction->deploy["activated"]     = '激活上線計劃';
$lang->action->dynamicAction->deploy['commented']     = '上線計劃備註';
$lang->action->dynamicAction->deploy["finished"]      = '完成上線計劃';
$lang->action->dynamicAction->deploy['deleted']       = '刪除上線計劃';
$lang->action->dynamicAction->deploy['undeleted']     = '還原上線計劃';
$lang->action->dynamicAction->deploy['hidden']        = '隱藏上線計劃';
$lang->action->dynamicAction->deploystep['created']   = '創建上線步驟';
$lang->action->dynamicAction->deploystep['edited']    = '編輯上線步驟';
$lang->action->dynamicAction->deploystep["finished"]  = '完成上線步驟';
$lang->action->dynamicAction->deploystep["assigned"]  = '指派上線步驟';
$lang->action->dynamicAction->deploystep['deleted']   = '刪除上線步驟';
$lang->action->dynamicAction->deploystep['undeleted'] = '還原上線步驟';
$lang->action->dynamicAction->deploystep['hidden']    = '隱藏上線步驟';

$lang->action->dynamicAction->host['created']   = '創建主機';
$lang->action->dynamicAction->host['edited']    = '編輯主機';
$lang->action->dynamicAction->host['online']    = '上架主機';
$lang->action->dynamicAction->host['offline']   = '下架主機';
$lang->action->dynamicAction->host['deleted']   = '刪除主機';
$lang->action->dynamicAction->host['undeleted'] = '還原主機';
$lang->action->dynamicAction->host['hidden']    = '隱藏主機';

$lang->action->dynamicAction->serverroom['created']   = '創建機房';
$lang->action->dynamicAction->serverroom['edited']    = '編輯機房';
$lang->action->dynamicAction->serverroom['deleted']   = '刪除機房';
$lang->action->dynamicAction->serverroom['undeleted'] = '還原機房';
$lang->action->dynamicAction->serverroom['hidden']    = '隱藏機房';

$lang->action->dynamicAction->service['created']   = '創建服務';
$lang->action->dynamicAction->service['edited']    = '編輯服務';
$lang->action->dynamicAction->service['deleted']   = '刪除服務';
$lang->action->dynamicAction->service['undeleted'] = '還原服務';
$lang->action->dynamicAction->service['hidden']    = '隱藏服務';

$lang->action->dynamicAction->attend['commited'] = '提交考勤';
$lang->action->dynamicAction->attend['reviewed'] = '審核考勤';

$lang->action->dynamicAction->leave['created']  = '創建請假';
$lang->action->dynamicAction->leave['edited']   = '編輯請假';
$lang->action->dynamicAction->leave['reviewed'] = '審核請假';
$lang->action->dynamicAction->leave['reported'] = '銷假';
$lang->action->dynamicAction->leave['revoked']  = '撤銷請假';
$lang->action->dynamicAction->leave['commited'] = '提交請假';

$lang->action->dynamicAction->makeup['created']  = '創建補班';
$lang->action->dynamicAction->makeup['edited']   = '編輯補班';
$lang->action->dynamicAction->makeup['reviewed'] = '審核補班';
$lang->action->dynamicAction->makeup['revoked']  = '撤銷補班';
$lang->action->dynamicAction->makeup['commited'] = '提交補班';

$lang->action->dynamicAction->overtime['created']  = '創建加班';
$lang->action->dynamicAction->overtime['edited']   = '編輯加班';
$lang->action->dynamicAction->overtime['reviewed'] = '審核加班';
$lang->action->dynamicAction->overtime['revoked']  = '撤銷加班';
$lang->action->dynamicAction->overtime['commited'] = '提交加班';

$lang->action->dynamicAction->lieu['created']  = '創建調休';
$lang->action->dynamicAction->lieu['edited']   = '編輯調休';
$lang->action->dynamicAction->lieu['reviewed'] = '審核調休';
$lang->action->dynamicAction->lieu['revoked']  = '撤銷調休';
$lang->action->dynamicAction->lieu['commited'] = '提交調休';

$lang->action->dynamicAction->holiday['created'] = '創建節假日';

$lang->action->dynamicAction->feedback['opened']    = '創建反饋';
$lang->action->dynamicAction->feedback['edited']    = '編輯反饋';
$lang->action->dynamicAction->feedback['reviewed']  = '審核反饋';
$lang->action->dynamicAction->feedback['asked']     = '追問反饋';
$lang->action->dynamicAction->feedback['replied']   = '回覆反饋';
$lang->action->dynamicAction->feedback['commented'] = '評論反饋';
$lang->action->dynamicAction->feedback['assigned']  = '指派反饋';
$lang->action->dynamicAction->feedback['tostory']   = '反饋轉' . $lang->SRCommon;
$lang->action->dynamicAction->feedback['tobug']     = '反饋轉Bug';
$lang->action->dynamicAction->feedback['totask']    = '反饋轉任務';
$lang->action->dynamicAction->feedback['totodo']    = '反饋轉待辦';
$lang->action->dynamicAction->feedback['closed']    = '關閉反饋';

==> ZenTaoPMS-20.0-php7.2_7.4.zip: zentaopms/extension/max/action/ext/lang/zh-tw/zentaobiz.php <==
<?php
$lang->action->dynamicAction->bug['fromfeedback']   = '由反饋創建Bug';
$lang->action->dynamicAction->story['fromfeedback'] = '由反饋創建' . $lang->SRCommon;
$lang->action->dynamicAction->task['fromfeedback']  = '由反饋創建任務';
$lang->action->dynamicAction->todo['fromfeedback']  = '由反饋創建待辦';

$lang->action->dynamicAction->deploy['created']       = '創建上線計劃';
$lang->action->dynamicAction->deploy['edited']        = '編輯上線計劃';
$lang->action->dynamicAction->deploy["activated"]     = '激活上線計劃';
$lang->action->dynamicAction->deploy['commented']     = '上線計劃備註';
$lang->action->dynamicAction->deploy["finished"]      = '完成上線計劃';
$lang->action->dynamicAction->deploy['deleted']       = '刪除上線計劃';
$lang->action->dynamicAction->deploy['undeleted']     = '還原上線計劃';
$lang->action->dynamicAction->deploy['hidden']        = '隱藏上線計劃';
$lang->action->dynamicAction->deploystep['created']   = '創建上線步驟';
$lang->action->dynamicAction->deploystep['edited']    = '編輯上線步驟';
$lang->action->dynamicAction->deploystep["finished"]  = '完成上線步驟';
$lang->action->dynamicAction->deploystep["assigned"]  = '指派上線步驟';
$lang->action->dynamicAction->deploystep['deleted']   = '刪除上線步驟';
$lang->action->dynamicAction->deploystep['undeleted'] = '還原上線步驟';
$lang->action->dynamicAction->deploystep['hidden']    = '隱藏上線步驟';

$lang->action->dynamicAction->host['created']   = '創建主機';
$lang->action->dynamicAction->host['edited']    = '編輯主機';
$lang->action->dynamicAction->host['online']    = '上架主機';
$lang->action->dynamicAction->host['offline']   = '下架主機';
$lang->action->dynamicAction->host['deleted']   = '刪除主機';
$lang->action->dynamicAction->host['undeleted'] = '還原主機';
$lang->action->dynamicAction->host['hidden']    = '隱藏主機';

$lang->action->dynamicAction->serverroom['created']   = '創建機房';
$lang->action->dynamicAction->serverroom['edited']    = '編輯機房';
$lang->action->dynamicAction->serverroom['deleted']   = '刪除機房';
$lang->action->dynamicAction->serverroom['undeleted'] = '還原機房';
$lang->action->dynamicAction->serverroom['hidden']    = '隱藏機房';

$lang->action->dynamicAction->service['created']   = '創建服務';
$lang->action->dynamicAction->service['edited']    = '編輯服務';
$lang->action->dynamicAction->service['deleted']   = '刪除服務';
$lang->action->dynamicAction->service['undeleted'] = '還原服務';
$lang->action->dynamicAction->service['hidden']    = '隱藏服務';

$lang->action->dynamicAction->attend['commited'] = '提交考勤';
$lang->action->dynamicAction->attend['reviewed'] = '審核考勤';

$lang->action->dynamicAction->leave['created']  = '創建請假';
$lang->action->dynamicAction->leave['edited']   = '編輯請假';
$lang->action->dynamicAction->leave['reviewed'] = '審核請假';
$lang->action->dynamicAction->leave['reported'] = '銷假';
$lang->action->dynamicAction->leave['revoked']  = '撤銷請假';
$lang->action->dynamicAction->leave['commited'] = '提交請假';

$lang->action->dynamicAction->makeup['created']  = '創建補班';
$lang->action->dynamicAction->makeup['edited']   = '編輯補班';
$lang->action->dynamicAction->makeup['reviewed'] = '審核補班';
$lang->action->dynamicAction->makeup['revoked']  = '撤銷補班';
$lang->action->dynamicAction->makeup['commited'] = '提交補班';

$lang->action->dynamicAction->overtime['created']  = '創建加班';
$lang->action->dynamicAction->overtime['edited']   = '編輯加班';
$lang->action->dynamicAction->overtime['reviewed'] = '審核加班';
$lang->action->dynamicAction->overtime['revoked']  = '撤銷加班';
$lang->action->dynamicAction->overtime['commited'] = '提交加班';

$lang->action->dynamicAction->lieu['created']  = '創建調休';
$lang->action->dynamicAction->lieu['edited']   = '編輯調休';
$lang->action->dynamicAction->lieu['reviewed'] = '審核調休';
$lang->action->dynamicAction->lieu['revoked']  = '撤銷調休';
$lang->action->dynamicAction->lieu['commited'] = '提交調休';

$lang->action->dynamicAction->holiday['created'] = '創建節假日';

$lang->action->dynamicAction->feedback['opened']      = '創建反饋';
$lang->action->dynamicAction->feedback['edited']      = '編輯反饋';
$lang->action->dynamicAction->feedback['reviewed']    = '審核反饋';
$lang->action->dynamicAction->feedback['asked']       = '追問反饋';
$lang->action->dynamicAction->feedback['replied']     = '回覆反饋';
$lang->action->dynamicAction->feedback['commented']   = '評論反饋';
$lang->action->dynamicAction->feedback['assigned']    = '指派反饋';
$lang->action->dynamicAction->feedback['tostory']     = '反饋轉' . $lang->SRCommon;
$lang->action->dynamicAction->feedback['touserstory'] = '反饋轉' . $lang->URCommon;
$lang->action->dynamicAction->feedback['tobug']       = '反饋轉Bug';
$lang->action->dynamicAction->feedback['totask']      = '反饋轉任務';
$lang->action->dynamicAction->feedback['totodo']      = '反饋轉待辦';
$lang->action->dynamicAction->feedback['closed']      = '關閉反饋';

$lang->action->dynamicAction->ticket['create']   = '創建工單';
$lang->action->dynamicAction->ticket['edited']   = '編輯工單';
$lang->action->dynamicAction->ticket['started']  = '開始工單';
$lang->action->dynamicAction->ticket['finished'] = '完成工單';
$lang->action->dynamicAction->ticket['closed']   = '關閉工單';
$lang->action->dynamicAction->ticket['assigned'] = '指派工單';
$lang->action->dynamicAction->ticket['tostory']  = '工單轉' . $lang->SRCommon;
$lang->action->dynamicAction->ticket['tobug']    = '工單轉Bug';

$lang->action->objectTypes['dashboard']  = '儀表盤';
$lang->action->objectTypes['chart']      = '圖表';
$lang->action->objectTypes['pivot']      = '透視表';
$lang->action->objectTypes['screen']     = '大屏';
$lang->action->objectTypes['dimension']  = '維度';
$lang->action->objectTypes['chartgroup'] = '分組';

$lang->action->label->designed      = '設計了';
$lang->action->label->updated       = '更新了';
$lang->action->label->chartreleased = '發佈了';
$lang->action->label->pivotreleased = '發佈了';

if(!$config->URAndSR) unset($lang->action->dynamicAction->feedback['touserstory']);
